@@ -1,7 +1,7 @@
 package Module::List::Wildcard;
 
 our $DATE = '2020-12-22'; # DATE
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 #IFUNBUILT
 # # use strict 'subs', 'vars';
@@ -212,7 +212,7 @@ Module::List::Wildcard - A fork of Module::List that groks wildcard
 
 =head1 VERSION
 
-This document describes version 0.004007 of Module::List::Wildcard (from Perl distribution Module-List-Wildcard), released on 2020-12-22.
+This document describes version 0.004008 of Module::List::Wildcard (from Perl distribution Module-List-Wildcard), released on 2020-12-22.
 
 =head1 SYNOPSIS
 
@@ -317,7 +317,14 @@ feature.
 
 =head1 SEE ALSO
 
-L<Module::List>, L<Module::List::Tiny>, L<Module::List::More>
+L<Module::List>
+
+L<Module::List::Tiny>
+
+L<Module::List::More>, from which Module::List::Wildcard is forked from.
+Module::List::More contains more features, including wildcard support, but
+currently I'm maintainng both. Eventually this duplication might be resolved in
+the future.
 
 =head1 AUTHOR
 
